#include "def_vst.h"

MAIN
{
    short   *frame;         /*  signal frame                          */

    float   rms;            /*  root of mean squares                  */
    bool    dB;             /*  see option -D                         */

    int     fr,             /*  frame rate                            */
            i;              /*                                        */

    static char *synopsis =
"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n"
" basic arithmetic signal operations      V1.0,  19.12.1995,  V.Strom \n"
"                                                                     \n"
" usage:   sig_ene fr  < sig  > ene                                   \n"
"                                                                     \n"
" sig   signal                                 (shorts)               \n"
" ene   RMS, one per frame                     (floats)               \n"
" fr    frame rate in samples                  (int)                  \n"
"                                                                     \n"
" RMS = sqrt(sum{s[i]}/fr)                                            \n"
"                                                                     \n"
" Options:                                                            \n"
"                                                                     \n"
" -D    output RMS in dB: 20 * log10(RMS)                             \n"
"                                                                     \n"
"~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n";
    ARGS(1,"D","");
    
    IARG(1, fr);
    BOPT('D', dB);

    ALLOCATE(frame, short, fr);

    /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
    /*                 main loop                                     */
    /*_______________________________________________________________*/


    while(FREAD(frame, short, UP_TO, fr, stdin)==fr)
    {
        for(rms=0,i=0; i<fr; i++)
            rms += SQR(frame[i]);

        rms /= fr;
        rms = sqrt(rms);
        if(dB)
            rms = 20 * log10(rms);
        FWRITE(&rms, float, 1, stdout);
    }
    /*---------------------------------------------------------------*/
    return 0;
}
